@@ -1,7 +1,7 @@
 /*
  * pxp_lib - a user space library for PxP
  *
- * Copyright (C) 2013-2016 Freescale Semiconductor, Inc.
+ * Copyright (C) 2010 Freescale Semiconductor, Inc.
  */
 
 /*
@@ -21,8 +21,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <pthread.h>
-#include <string.h>
 
 #include "pxp_lib.h"
 
@@ -38,28 +36,23 @@ static int debug_level = DBG_ERR;
 
 static int fd = -1;
 static int active_open_nr;
-static pthread_mutex_t lock;
 
 int pxp_init(void)
 {
-	pthread_mutex_lock(&lock);
 	if (fd > 0) {
 		active_open_nr++;
-		pthread_mutex_unlock(&lock);
 		return 0;
 	}
 
 	if (fd < 0) {
 		fd = open(PXP_DEVICE_NAME, O_RDWR, 0);
 		if (fd < 0) {
-			pthread_mutex_unlock(&lock);
 			dbg(DBG_ERR, "open file error.\n");
 			return -1;
 		}
 	}
 
 	active_open_nr++;
-	pthread_mutex_unlock(&lock);
 	return 0;
 }
 
@@ -72,26 +65,21 @@ int pxp_request_channel(pxp_chan_handle_t *pxp_chan)
 	if (ret < 0)
 		return -1;
 
-	pxp_chan->handle = cid;
+	pxp_chan->chan_id = cid;
 	return 0;
 }
 
 void pxp_release_channel(pxp_chan_handle_t *pxp_chan)
 {
-	ioctl(fd, PXP_IOC_PUT_CHAN, &(pxp_chan->handle));
+	ioctl(fd, PXP_IOC_PUT_CHAN, &(pxp_chan->chan_id));
 }
 
 int pxp_config_channel(pxp_chan_handle_t *pxp_chan, struct pxp_config_data *pxp_conf)
 {
 	int ret = 0;
 
-	pxp_conf->handle = pxp_chan->handle;
-	dbg(DBG_INFO, "channel handle %d\n\n", pxp_conf->handle);
-
-#ifdef PXP_DEVICE_LEGACY
-        dbg(DBG_INFO, "use legacy pxp driver\n");
-        pxp_conf->proc_data.pxp_legacy = true;
-#endif
+	pxp_conf->chan_id = pxp_chan->chan_id;
+	dbg(DBG_INFO, "chan_id %d\n\n", pxp_conf->chan_id);
 
 	ret = ioctl(fd, PXP_IOC_CONFIG_CHAN, pxp_conf);
 
@@ -102,7 +90,7 @@ int pxp_start_channel(pxp_chan_handle_t *pxp_chan)
 {
 	int ret = 0;
 
-	ret = ioctl(fd, PXP_IOC_START_CHAN, &(pxp_chan->handle));
+	ret = ioctl(fd, PXP_IOC_START_CHAN, &(pxp_chan->chan_id));
 
 	return ret;
 }
@@ -124,11 +112,8 @@ int pxp_wait_for_completion(pxp_chan_handle_t *pxp_chan, int times)
 
 void pxp_uninit(void)
 {
-	pthread_mutex_lock(&lock);
-	if (fd == -1) {
-		pthread_mutex_unlock(&lock);
+	if (fd == -1)
 		return;
-	}
 
 	if (active_open_nr > 1) {
 		active_open_nr--;
@@ -139,7 +124,6 @@ void pxp_uninit(void)
 			fd = -1;
 		}
 	}
-	pthread_mutex_unlock(&lock);
 }
 
 /*
@@ -149,11 +133,12 @@ int pxp_get_phymem(struct pxp_mem_desc *mem)
 {
 	if (ioctl(fd, PXP_IOC_GET_PHYMEM, mem) < 0) {
 		mem->phys_addr = 0;
+		mem->cpu_addr = 0;
 		dbg(DBG_ERR, "PXP_IOC_GET_PHYMEM err\n");
 		return -1;
 	}
 
-	dbg(DBG_INFO, "succeed mem.phys_addr = 0x%08lx\n", mem->phys_addr);
+	dbg(DBG_INFO, "succeed mem.phys_addr = 0x%08x\n", mem->phys_addr);
 	return 0;
 }
 
@@ -161,6 +146,7 @@ int pxp_put_phymem(struct pxp_mem_desc *mem)
 {
 	if (ioctl(fd, PXP_IOC_PUT_PHYMEM, mem) < 0) {
 		mem->phys_addr = 0;
+		mem->cpu_addr = 0;
 		dbg(DBG_ERR, "PXP_IOC_PUT_PHYMEM err\n");
 		return -1;
 	}
@@ -182,8 +168,8 @@ int pxp_get_virtmem(struct pxp_mem_desc *mem)
 		return -1;
 	}
 
-	mem->virt_uaddr = va_addr;
-	dbg(DBG_INFO, "virt addr = %p\n", mem->virt_uaddr);
+	mem->virt_uaddr = (unsigned long)va_addr;
+	dbg(DBG_INFO, "virt addr = %08x\n", mem->virt_uaddr);
 
 	return 0;
 }
@@ -191,7 +177,7 @@ int pxp_get_virtmem(struct pxp_mem_desc *mem)
 int pxp_put_virtmem(struct pxp_mem_desc *mem)
 {
 	if (mem->virt_uaddr != 0) {
-		if (munmap((void*)(intptr_t)mem->virt_uaddr, mem->size) != 0)
+		if (munmap((void *)mem->virt_uaddr, mem->size) != 0)
 			dbg(DBG_ERR, "UNMAP_FAILED.\n");
 	}
 
@@ -227,20 +213,3 @@ int pxp_put_mem(struct pxp_mem_desc *mem)
 
 	return 0;
 }
-
-int pxp_get_buf_from_fd(int fd)
-{
-	struct dma_buf_phys query;
-	int physAddr = 0;
-	int ret;
-
-	memset(&query, 0x0, sizeof(struct dma_buf_phys));
-	ret = ioctl(fd, DMA_BUF_IOCTL_PHYS, &query);
-	if (ret < 0) {
-		dbg(DBG_ERR, "%s: Can't get buffer from file descriptor\n", __func__);
-		return ret;
-	}
-	physAddr = (int)query.phys;
-
-	return physAddr;
-}
