@@ -1,7 +1,7 @@
 /*
  * pxp_lib - a user space library for PxP
  *
- * Copyright (C) 2010-2013 Freescale Semiconductor, Inc.
+ * Copyright (C) 2010 Freescale Semiconductor, Inc.
  */
 
 /*
@@ -16,8 +16,7 @@
 #ifndef	PXP_LIB_H
 #define	PXP_LIB_H
 
-#include <linux/pxp_device.h>
-#include <linux/dma-buf.h>
+#include <linux/pxp_dma.h>
 
 #ifndef true
 #define true    1
@@ -26,7 +25,10 @@
 #define false   0
 #endif
 
-typedef struct pxp_chan_handle pxp_chan_handle_t;
+typedef struct pxp_chan_handle {
+	int chan_id;
+	int hist_status;
+} pxp_chan_handle_t;
 
 int pxp_init();
 void pxp_uninit();
@@ -37,6 +39,5 @@ int pxp_start_channel(pxp_chan_handle_t *pxp_chan);
 int pxp_wait_for_completion(pxp_chan_handle_t *pxp_chan, int times);
 int pxp_get_mem(struct pxp_mem_desc *mem);
 int pxp_put_mem(struct pxp_mem_desc *mem);
-int pxp_get_buf_from_fd(int fd);
 
 #endif
